<?php
/*
Plugin Name: Page Lock
Description: With this plugin you can limit changes in page options and deleting selected pages.
Version: 1.01
Author: Michał Gańko
Author URI: http://foureyes.pl
*/

# get correct id for plugin
$thisfile=basename(__FILE__, ".php");

# register plugin
register_plugin(
	$thisfile, 
	'Page Lock', 	
	'1.01', 		
	'Michał Gańko',
	'http://foureyes.pl', 
	'With this plugin you can limit changes in page options and deleting selected pages.',
	'plugins',
	'page_lock_admin_tab'  
);


add_action('edit-extras','page_lock_on_edit_extras'); 
add_action('pages-main','page_lock_on_pages_main'); 
add_action('header','page_lock_on_header'); 

add_action('plugins-sidebar', 'createSideMenu', array($thisfile, 'Configure Page Lock'));





//delete lock security check
if (basename($_SERVER['PHP_SELF'])=='deletefile.php') {
	 if (isset($_GET['id'])) { 
		 $id = $_GET['id'];
		 $settings = page_lock_get_settings();
		 if ($settings->delete_lock && in_array($id , $settings->delete_slugs)){
			die('Page Lock plugin: delete lock!');
		 }
	 }
}

//page options lock security check
if (basename($_SERVER['PHP_SELF'])=='changedata.php') {

	if ( isset($_POST['existing-url']) ){ //if editing currently existing page
	
		$oldSlug = $_POST['existing-url'];
		$newSlug = $_POST['post-id'];
		$settings = page_lock_get_settings();
		
		if (in_array($oldSlug , $settings->options_slugs)){
		
			$file = GSDATAPAGESPATH . $oldSlug .".xml";
			$oldData = getXML($file);

			if ($settings->slug_lock && $oldSlug != $newSlug){
				die('Page Lock plugin: slug lock!');
			}
			if ($settings->visibility_lock && $_POST['post-private'] != (string)$oldData->private){
				die('Page Lock plugin: visibility lock!');
			}	
			if ($settings->template_lock && $_POST['post-template'] != (string)$oldData->template){
				die('Page Lock plugin: template lock!');
			}	
			if ($settings->parent_lock && $_POST['post-parent'] != (string)$oldData->parent){
				die('Page Lock plugin: parent lock!');
			}	
		}
	}
}



function page_lock_admin_tab() {
	if (isset($_POST['options_slugs'])){ //is post
	
		$visibility_lock = !empty($_POST['visibility_lock'])?1:0;
		$template_lock = !empty($_POST['template_lock'])?1:0;
		$parent_lock = !empty($_POST['parent_lock'])?1:0;
		$slug_lock = !empty($_POST['slug_lock'])?1:0;
		
		$delete_lock = !empty($_POST['delete_lock'])?1:0;
		
		$success = page_lock_save_settings($visibility_lock, $template_lock, $parent_lock, 
						$slug_lock, $_POST['options_slugs'], $delete_lock,  $_POST['delete_slugs']);
	}

	$settings = page_lock_get_settings();
	
	require_once('PageLock/form_template.php');
}

//removes private button from i18n_navigation Edit Navigation Structure option
function page_lock_on_header(){
	if (basename($_SERVER['PHP_SELF'])=='load.php') {
	
		if (isset($_GET['id']) && $_GET['id'] == 'i18n_navigation')  { 
			$settings = page_lock_get_settings();
			
			if (!$settings->visibility_lock)
				return;
			
			if (empty($_POST)){ //showing structure
				
				$len = count($settings->options_slugs);
				if ($len){
					echo '<script>$( document ).ready(function() {';
					foreach ($settings->options_slugs as $value)
					{
						echo '$(\'#editnav tr#tr-'.$value.' a.togglePrivate\').remove();';
					}
					echo '});</script>';
				}
			}
			
			//page options lock security check when saving data from Edit Navigation Structure
			if (!empty($_POST['save'])){ //saving
			
				for ($i=0; isset($_POST['page_'.$i.'_url']); $i++) {
					$slug = $_POST['page_'.$i.'_url'];
					if (in_array($slug , $settings->options_slugs)){
						$file = GSDATAPAGESPATH . $slug .".xml";
						$oldData = getXML($file);

						if ($_POST['page_'.$i.'_private'] !== (string)$oldData->private)
							die('Page Lock plugin: private lock (i18n_navigation)!');
					}
				}
			}	
		}
		 
		//removes delete button from Special Pages of type... menu show 
		if (isset($_GET['id']) && $_GET['id'] == 'i18n_specialpages' && isset($_GET['pages']) && isset($_GET['special']))  { 
			$settings = page_lock_get_settings();
			
			if (!$settings->delete_lock)
				return;

			$len = count($settings->delete_slugs);
			if ($len){
				echo '<script>$( document ).ready(function() {';
				foreach ($settings->delete_slugs as $value)
				{
					echo '$(\'a[href^="deletefile.php?id='.$value.'&"]\').remove();';
				}
				echo '});</script>';
			}
		}
		 
	}
}

//removes delete buttons from pages list
function page_lock_on_pages_main() {
	$settings = page_lock_get_settings();
	//if on restriction list, disable delet ebutton on pages list
	$len = count($settings->delete_slugs);
	if ($settings->delete_lock && $len){
		echo '<script>$( document ).ready(function() {';
		foreach ($settings->delete_slugs as $value)
		{
		  echo '$(\'#editpages a.delconfirm[href^="deletefile.php?id='.$value.'&"]\').remove();';
		}
		echo '});</script>';
	}
}

//disables page option fields
function page_lock_on_edit_extras() {
	global $url; //here is slug
	
	$settings = page_lock_get_settings();
	
	$script = '<script>$( document ).ready(function() {';
	
	//prepare page options
	if (in_array($url , $settings->options_slugs)){
		if ($settings->slug_lock){
			$script .= '$("#post-id").attr("readonly", "readonly");';
		}	
		if ($settings->visibility_lock){
			$script .= '$("#post-private").attr("disabled", "disabled");';
		}	
		if ($settings->parent_lock){
			$script .= '$("#post-parent").attr("disabled", "disabled");';
		}		
		if ($settings->template_lock){
			$script .= '$("#post-template").attr("disabled", "disabled");';
		}
		
		//remove disabled attribute before submitting, for sending POST data
		$script .= '
			$(\'#editform\').bind(\'submit\', function() {
				$(this).find(\'select\').removeAttr(\'disabled\');
			});
		';
		
	}
	
	//disable delete option from dropdown next to save button
	if ($settings->delete_lock && in_array($url , $settings->delete_slugs)){
		$script .= '$(\'a[href^="deletefile.php?id='.$url.'&"]\').remove();';
	}
	
	$script .= '});</script>'; //close script
	
	echo $script;
}

//retrieves settings from xml
function page_lock_get_settings() {
    $file = GSDATAOTHERPATH . 'pagelock.xml';
	
	if (!file_exists($file)) {
		page_lock_save_settings(); //create empty one
	}
	
	$data = getXML($file);
	
	$settings = new stdClass();

	$settings->visibility_lock = (bool) (string) $data->visibility_lock;
	$settings->template_lock = (bool) (string) $data->template_lock;
	$settings->parent_lock = (bool) (string) $data->parent_lock;
	$settings->slug_lock = (bool) (string) $data->slug_lock;
	
	$settings->options_slugs = explode(',',(string)$data->options_slugs);
	
	
	$settings->delete_lock = (bool) (string) $data->delete_lock;
	$settings->delete_slugs =  explode(',',(string)$data->delete_slugs);
	
	return $settings;
}

//saves settings to xml
function page_lock_save_settings($visibility_lock = 0, $template_lock = 0, $parent_lock = 0, 
								$slug_lock = 0, $options_slugs = '', $delete_lock = 0, $delete_slugs = '') {
    $file = GSDATAOTHERPATH . 'pagelock.xml';
	
	$xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><settings></settings>');
	$xml->addChild('visibility_lock', $visibility_lock);
	$xml->addChild('template_lock', $template_lock);
	$xml->addChild('parent_lock', $parent_lock);
	$xml->addChild('slug_lock', $slug_lock);
	
	$xml->addChild('delete_lock', $delete_lock);
	
	$obj = $xml->addChild('options_slugs');
	$obj->addCData($options_slugs);	
	
	$obj = $xml->addChild('delete_slugs');
	$obj->addCData($delete_slugs);
	
	  # write data to file
	return XMLsave($xml, $file);
}